/*
 *                            *
 *                           * *
 *                          *   *
 *                     ***************
 *                      * *       * *
 *                       *  MUMPS  *
 *                      * *       * *
 *                     ***************
 *                          *   *
 *                           * *
 *                            *
 *
 *   mappings.h
 *    Support of global/routine mappings
 *
 *  
 *   Author: John P. Willis <jpw@coherent-logic.com>
 *    Copyright (C) 1998 MUG Deutschland
 *    Copyright (C) 2020 Coherent Logic Development LLC
 *
 *
 *   This file is part of FreeM.
 *
 *   FreeM is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU Affero Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   FreeM is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Affero Public License for more details.
 *
 *   You should have received a copy of the GNU Affero Public License
 *   along with FreeM.  If not, see <https://www.gnu.org/licenses/>.
 *
 **/

#ifndef _MAPPINGS_H
#define _MAPPINGS_H

#define MAPPINGS_MAX 1024

#define MAPT_DEL 0 // this mapping has been deleted
#define MAPT_RTN 1 // this mapping is for a routine
#define MAPT_GBL 2 // this mapping is for a global

typedef struct mapping_ent_t {
	
	/* MAPT_RTN or MAPT_GLOBAL */
	short mapping_type;

	/* The identifier to be mapped */
	char identifier[1024];

	/* The target namespace */
	char namespace[256];

} mapping_ent_t;

void init_mappings();
short map_get(short m_type, char *m_ident, char *buf);
short map_add(short m_type, char *m_ident, char *namespace);
short map_delete(short m_type, char *m_ident);

#endif